#!/usr/bin/python
# -*- coding=utf-8 -*-
# µBackup 5.0 (5.0.0)
# Completely rewritten in Python ;)

import os, sys, locale, gettext, ulib

# These lines are needed to translate automatically this application
# into supported languages
app_name = 'ubackup'
local_path = os.path.realpath(os.path.dirname(sys.argv[0])) + "/i18n"
langs = []
lc, encoding = locale.getdefaultlocale()
if (lc):
    langs = [lc]
language = os.environ.get('LANGUAGE', None)
if (language):
    langs += language.split(":")
langs += ["en_US", "it_IT"]
gettext.bindtextdomain(app_name, local_path)
gettext.textdomain(app_name)
lang = gettext.translation(app_name, local_path
	, languages=langs, fallback = True)
_ = gettext.gettext

# Help text
help = _("""
uBackup 5.0
Usage: ubackup <option> <directory>
    
Options:

    -b, --bz2             Makes an archive in tar.bz2 format.
    -c, --cron            Starts Cron configurator.
    -g, --gz              Makes an archive in tar.gz format.
    -h, --help            Shows this help.
    -z, --zip             Makes an archive in zip format.

Just add 'f' before the archive format you want to upload the archive on the FTP server you need to backup to.
e.g.: ubackup -fg /path/to/file
      ubackup --fgz /path/to/file
If you haven't already configured the FTP parameters, you'll be prompted to the µBackup Settings Manager to complete the configuration.
""")

# Check that the user has passed an argument
if len(sys.argv) < 1:
    print help
    sys.exit(1)

# This code analyzes the arguments given by user and executes the chosen action
# of, if there's something wrong, shows an error to the user.
if "--help" in sys.argv or "-h" in sys.argv:
    print help
if "--bz2" in sys.argv or "-b" in sys.argv:
    if "--bz2" in sys.argv:
        ulib.bk('b', sys.argv[sys.argv.index("--bz2")+1])
    else:
        ulib.bk('b', sys.argv[sys.argv.index("-b")+1])
elif "--gz" in sys.argv or "-g" in sys.argv:
    if "--gz" in sys.argv:
        ulib.bk('g', sys.argv[sys.argv.index("--gz")+1])
    else:
        ulib.bk('g', sys.argv[sys.argv.index("-g")+1])
elif "--zip" in sys.argv or "-z" in sys.argv:
    if "--zip" in sys.argv:
        ulib.bk('z', sys.argv[sys.argv.index("--zip")+1])
    else:
        ulib.bk('z', sys.argv[sys.argv.index("-z")+1])
elif "--fbz2" in sys.argv or "-fb" in sys.argv:
    if "--fbz2" in sys.argv:
        ulib.ftpbk('b', sys.argv[sys.argv.index("--fbz2")+1])
    else:
        ulib.ftpbk('b', sys.argv[sys.argv.index("-fb")+1])
elif "--fgz" in sys.argv or "-fg" in sys.argv:
    if "--fgz" in sys.argv:
        ulib.ftpbk('g', sys.argv[sys.argv.index("--fgz")+1])
    else:
        ulib.ftpbk('g', sys.argv[sys.argv.index("-fg")+1])
elif "--fzip" in sys.argv or "-fz" in sys.argv:
    if "--fzip" in sys.argv:
        ulib.ftpbk('z', sys.argv[sys.argv.index("--fzip")+1])
    else:
        ulib.ftpbk('z', sys.argv[sys.argv.index("-fz")+1])
elif "--cron" in sys.argv or "-fz" in sys.argv:
        ulib.cronconfig()
else:
    print help
    sys.exit(1)
